@@ -37,10 +37,11 @@ fi
 
 tag="v$version"
 
+perl -pi -e "s/(?<=Version = \").+?(?=\")/$version/g" pkg/geoipupdate/version.go
+
 echo $'\nRelease notes:'
 echo "$notes"
 
-
 read -p "Continue? (y/n) " ok
 
 if [ "$ok" != "y" ]; then
@@ -48,6 +49,10 @@ if [ "$ok" != "y" ]; then
     exit 1
 fi
 
+git commit -m "Update for $tag" -a
+
+git push
+
 echo "Creating tag $tag"
 
 message="$version
@@ -64,24 +69,3 @@ git push
 rm -rf dist
 goreleaser release --rm-dist -f .goreleaser.yml --release-notes <(echo "$message")
 make clean BUILDDIR=.
-
-rm -rf dist
-goreleaser release --rm-dist -f .goreleaser-windows.yml --skip-publish
-hub release edit -m "$message" \
-    -a "dist/geoipupdate_${version}_windows_386.zip" \
-    -a "dist/geoipupdate_${version}_windows_amd64.zip" \
-    -a dist/checksums-windows.txt \
-    "$tag"
-make clean BUILDDIR=.
-
-rm -rf dist
-goreleaser release --rm-dist -f .goreleaser-packages.yml --skip-publish
-
-hub release edit -m "$message" \
-    -a dist/checksums-dpkg-rpm.txt \
-    -a "dist/geoipupdate_${version}_linux_386.deb" \
-    -a "dist/geoipupdate_${version}_linux_amd64.deb" \
-    -a "dist/geoipupdate_${version}_linux_386.rpm" \
-    -a "dist/geoipupdate_${version}_linux_amd64.rpm" \
-    "$tag"
-make clean BUILDDIR=.
